# Manage simulation models

```{warning}
Incomplete documentation.
```

## Main steps

### Receive

- setting workflows
- Interface to CalibPipe / other pipelines / telescope teams
- Input data description (e.g., what calibration data is required to derive the optical PSF or the single photo-electron spectrum)

### Derive

- detailed description of each setting workflows

### Validate

- validation workflows

### View

- reporting on model parameters
- reporting on setting and validation

## Maintenance

- [Maintenance of simulation models databases](manage_simulation_models/simulation_models_database.md)
- [Import simulation model parameters](manage_simulation_models/model_import.md)

```{toctree}
:hidden:
:glob: true
:maxdepth: 1
manage_simulation_models/simulation_models_database.md
manage_simulation_models/model_import.md
```
